rmst_point_estimate: Calculate the point estimate of the marginal restricted mean...

View source: R/rmst_point_estimate.R

rmst_point_estimateR Documentation

Calculate the point estimate of the marginal restricted mean survival time (RMST) when adjusting covariates in clinical trials

Description

Estimate the marginal RMST (point estimate) using the Karrison et al.(2018).

Usage

rmst_point_estimate(fit, dt, tau)

Arguments

fit

A coxph object with strata(trt) in the model. See example.

dt

A data frame used for the fit - coxph model including survival time, OS status, trt, and covariates.

tau

Numeric. A value for the restricted time or the pre-specified cutoff time point.

Details

Restricted mean survival time is a measure of average survival time up to a specified time point. We adopted the methods from Karrison et al.(2018) for estimating the marginal RMST when adjusting covariates.

Value

A list containing the RMST, cumulative survival function, and cumulative hazard function.

output

Marginal RMST

surv0

Cumulative survival function for the placebo group

cumhaz0

Cumulative hazard function for the placebo group

surv1

Cumulative survival function for the treatment group

cumhaz1

Cumulative hazard function for the treatment group

References

  • Karrison T, Kocherginsky M. Restricted mean survival time: Does covariate adjustment improve precision in randomized clinical trials? Clinical Trials. 2018;15(2):178-188. doi:10.1177/1740774518759281

  • Zucker, D. M. (1998). Restricted Mean Life with Covariates: Modification and Extension of a Useful Survival Analysis Method. Journal of the American Statistical Association, 93(442), 702–709. https://doi.org/10.1080/01621459.1998.10473722

  • Wei, J., Xu, J., Bornkamp, B., Lin, R., Tian, H., Xi, D., … Roychoudhury, S. (2024). Conditional and Unconditional Treatment Effects in Randomized Clinical Trials: Estimands, Estimation, and Interpretation. Statistics in Biopharmaceutical Research, 16(3), 371–381. https://doi.org/10.1080/19466315.2023.2292774

  • Chen, P. and Tsiatis, A. (2001), “Causal Inference on the Difference of the Restricted Mean Lifetime Between Two Groups,” Biometrics; 57: 1030–1038. DOI: 10.1111/j.0006-341x.2001.01030.x.

Examples

library(survival)
data("oak")

tau <- 26
time <- oak$OS
status <- oak$os.status
trt <- oak$trt
covariates <- oak[, c("btmb", "pdl1")]
dt <- as.data.frame(cbind(time, status, trt, covariates))
fit <- coxph(Surv(time, status) ~ btmb + pdl1 + strata(trt), data = dt)
delta <- rmst_point_estimate(fit, dt = dt, tau)
delta$output

bunsen documentation built on June 8, 2025, 11:34 a.m.