If the study period for the original data is divided into discrete windows,
defined by the event times in the original data, at time t0 = 0, everyone in the simulated data is still a survivor.
S(x) is the estimated survival function. By the end of the window (0,t1], a proportion S(t1) still survives.
The conditional probability of surviving the next window, (t1,t2], conditional on surviving the first window,
is S(t2)/S(t1), and so on. This function returns the S(t2)/S(t1) in series.