| rbinom_matrix_vec | R Documentation |
Create a matrix of size nrows by ncols where each column j uses its own success probability probs j.
rbinom_matrix_vec(nrows, ncols, probs)
nrows |
Integer, number of rows. |
ncols |
Integer, number of columns. |
probs |
Numeric vector of length ncols, column-wise success probabilities in (0, 1). |
IntegerMatrix of dimension nrows by ncols.
set.seed(1)
rbinom_matrix_vec(5, 3, rep(0.3, 3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.